@@ -1,5 +1,4 @@
 import dataclasses as dc
-import os
 import tarfile
 import time
 import typing as t
@@ -77,18 +76,27 @@ class GlobalCommandHandler(click.Group):
     def __call__(self, *args, **kwargs):
         try:
             return self.main(*args, **kwargs)
-        except utils.IncompatibleVersionException as exc:
+        except utils.IncompatibleVersionError as e:
             if EXTRA_OUT:
-                log.exception(exc)
-            failure_msg(str(exc))
+                log.exception(e)
+            failure_msg(str(e))
         except HTTPError as e:
             if EXTRA_OUT:
                 log.exception(e)
-            failure_msg(str(e), do_exit=True)
+            failure_msg(utils.add_help_text(str(e)), do_exit=True)
         except Exception as e:
             if EXTRA_OUT:
                 log.exception(e)
-            failure_msg(str(e), do_exit=True)
+            failure_msg(utils.add_help_text(str(e)), do_exit=True)
+
+
+def recursive_help(cmd, parent=None):
+    ctx = click.core.Context(cmd, info_name=cmd.name, parent=parent)
+    print(cmd.get_help(ctx))
+    print()
+    commands = getattr(cmd, "commands", {})
+    for sub in commands.values():
+        recursive_help(sub, ctx)
 
 
 ###############################################################################
@@ -111,6 +119,11 @@ def cli(ctx, verbose: int, env: str):
     ctx.obj = DPContext(env=env)
 
 
+# @cli.command()
+# def dumphelp():
+#     recursive_help(cli)
+
+
 ###############################################################################
 # Auth
 @cli.command()
@@ -119,7 +132,7 @@ def cli(ctx, verbose: int, env: str):
 @click.pass_obj
 def login(obj: DPContext, token, server):
     """Login to a server with the given API token."""
-    api.login(token, server, env=obj.env, cli_login=True)
+    api.login(token, server, env=obj.env)
     # click.launch(f"{server}/settings/")
 
 
@@ -161,11 +174,10 @@ def upload(file: str, name: str, visibility: str):
 @blob.command()
 @click.argument("name")
 @click.option("--owner")
-@click.option("--version")
 @click.argument("file", type=click.Path())
-def download(name: str, owner: str, version: str, file: str):
+def download(name: str, owner: str, file: str):
     """Download blob referenced by NAME to FILE"""
-    r = api.Blob.get(name, owner=owner, version=version)
+    r = api.Blob.get(name, owner=owner)
     r.download_file(file)
     success_msg(f"Downloaded {r.url} to {click.format_filename(file)}")
 
@@ -215,13 +227,12 @@ def write_templates(scaffold_name: str, context: SDict):
 
 
 @script.command(name="init")
-@click.argument("name", default=lambda: os.path.basename(os.getcwd()))
+@click.argument("name", default=lambda: sc.generate_name("Report"))
 def script_init(name: str):
     """Initialise a new script project"""
     if sc.DATAPANE_YAML.exists():
         failure_msg("Found existing project, cancelling", do_exit=True)
 
-    name = name.replace("-", "_")
     sc.validate_name(name)
     _context = dict(name=name)
 
@@ -242,7 +253,7 @@ def deploy(name: Optional[str], script: Optional[str], config: Optional[str], vi
     kwargs = {k: v for k, v in init_kwargs.items() if v is not None}
 
     # if not (script or config or sc.DatapaneCfg.exists()):
-    #     raise AssertationError(f"Not valid project dir")
+    #     raise DPError(f"Not valid project dir")
 
     dp_cfg = scripts.DatapaneCfg.create_initial(**kwargs)
     log.debug(f"Packaging and uploading Datapane project {dp_cfg.name}")
@@ -263,11 +274,10 @@ def deploy(name: Optional[str], script: Optional[str], config: Optional[str], vi
 
 @script.command()
 @click.argument("name")
-@click.option("--version")
 @click.option("--owner")
-def download(name: str, owner: str, version: str):
+def download(name: str, owner: str):
     """Download script referenced by NAME to FILE"""
-    s = api.Script.get(name, owner=owner, version=version)
+    s = api.Script.get(name, owner=owner)
     fn = s.download_pkg()
     success_msg(f"Downloaded {s.url} to {click.format_filename(str(fn))}")
 
@@ -350,7 +360,7 @@ def report():
 
 
 @report.command(name="init")
-@click.argument("name", default=lambda: os.path.basename(os.getcwd()))
+@click.argument("name", default=lambda: sc.generate_name("Script"))
 @click.option("--format", type=click.Choice(["notebook", "script"]), default="notebook")
 def report_init(name: str, format: str):
     """Initialise a new report"""
@@ -363,7 +373,6 @@ def report_init(name: str, format: str):
     if len(list(Path(".").glob("dp_report.*"))):
         failure_msg("Found existing project, cancelling", do_exit=True)
 
-    name = name.replace("-", "_")
     sc.validate_name(name)
     _context = dict(name=name)
 
@@ -385,14 +394,15 @@ def report_list():
     print_table(api.Report.list(), "Reports")
 
 
-@report.command()
-@click.argument("name")
-@click.option("--version")
-@click.option("--owner")
-@click.option("--filename", default="output.html", type=click.Path())
-def render(name: str, version: str, owner: str, filename: str):
-    """Render a report to a static file"""
-    api.Report.get(name, version=version, owner=owner).render()
+# NOTE - NYI - disabled
+# @report.command()
+# @click.argument("name")
+# @click.option("--version")
+# @click.option("--owner")
+# @click.option("--filename", default="output.html", type=click.Path())
+# def render(name: str, version: str, owner: str, filename: str):
+#     """Render a report to a static file"""
+#     api.Report.get(name, version=version, owner=owner).render()
 
 
 #############################################################################
@@ -432,11 +442,10 @@ def variable_list():
 @variable.command()
 @click.argument("name", required=True)
 @click.option("--owner")
-@click.option("--version")
 @click.option("--show", is_flag=True, help="Print the variable value.")
-def get(name, owner, version, show):
+def get(name, owner, show):
     """Get variable value using variable name"""
-    res = api.Variable.get(name, owner=owner, version=version)
+    res = api.Variable.get(name, owner=owner)
     if show:
         print(str(res.value).strip())
     else:
@@ -466,9 +475,8 @@ def schedule():
 @click.option("--parameter", "-p", multiple=True)
 @click.argument("name", required=True)
 @click.argument("cron", required=True)
-@click.option("--version")
 @click.option("--owner")
-def create(name: str, cron: str, parameter: Tuple[str], owner: str, version: str):
+def create(name: str, cron: str, parameter: Tuple[str], owner: str):
     """
     Create a schedule
 
@@ -476,11 +484,10 @@ def create(name: str, cron: str, parameter: Tuple[str], owner: str, version: str
     CRON: crontab representing the schedule interval
     PARAMETERS: key/value list of parameters to use when running the script on schedule
     [OWNER]: Script owner
-    [VERSION]: Script version
     """
     params = process_cmd_param_vals(parameter)
     log.info(f"Adding schedule with parameters {params}")
-    script_obj = api.Script.get(name, owner=owner, version=version)
+    script_obj = api.Script.get(name, owner=owner)
     schedule_obj = api.Schedule.create(script_obj, cron, params)
     success_msg(f"Created schedule: {schedule_obj.id} ({schedule_obj.url})")
 
